/*
    kopetechatwindow.h - Chat Window

    Copyright (c) 2002 by Olivier Goffart <ogoffart@tiscalinet.be>

    Kopete    (c) 2002 by the Kopete developers  <kopete-devel@kde.org>

    *************************************************************************
    *                                                                       *
    * This program is free software; you can redistribute it and/or modify  *
    * it under the terms of the GNU General Public License as published by  *
    * the Free Software Foundation; either version 2 of the License, or     *
    * (at your option) any later version.                                   *
    *                                                                       *
    *************************************************************************
*/

#ifndef KOPETECHATWINDOW_H
#define KOPETECHATWINDOW_H

#include <qstring.h>
#include <kmainwindow.h>
#include "kopetecontact.h"

namespace Kopete {
	class ChatView;
}

using Kopete::ChatView;

class KopeteMessage;
class KopeteMessageManager;
class KAction;
class KToggleAction;
class KActionMenu;
class KopeteContact;
class KTempFile;
class QPixmap;
class QTabWidget;
class KSqueezedTextLabel;
class KPushButton;
class QVBox;
class QVBoxLayout;
class QFrame;

typedef  QPtrList<KopeteContact>  KopeteContactPtrList;

/**
 * @author Olivier Goffart
 */
class KopeteChatWindow : public KMainWindow
{
	Q_OBJECT

public:
	KopeteChatWindow(QWidget *parent = 0, const char* name = "KopeteChatWindow" );
	~KopeteChatWindow();

	KopeteMessage currentMessage();
	ChatView *addChatView( KopeteMessageManager *manager );
	void addChatView( ChatView* );
	const int chatViewCount() { return chatViewList.count(); }
	ChatView *activeView();
	KTempFile *backgroundFile;
	QPtrList<ChatView> chatViewList;
	void updateMembersActions();
	void closeChat( ChatView* );
	void dockView( ChatView * );
	void setStatus( const QString & );
	void setSendEnabled( bool );
	virtual bool close( bool force = false );

	KAction *chatSend;
	KAction *historyUp;
	KAction *historyDown;

private:
	void initActions(void);
	void saveOptions(void);
	void readOptions(void);
	void checkDetachEnable();
	void createTabBar();
	void deleteTabBar();

	ChatView *m_activeView;
	bool widgetSet;
	bool tabsEnabled;
	const KopeteContact	*m_us;
	bool updateBg;
	QTabWidget *m_tabBar;
	KSqueezedTextLabel *m_status;
	KPushButton* m_button_send;
	QVBox *vBox;
	QVBoxLayout *mainLayout;
	QFrame *mainArea;

	KAction* editCut;
	KAction* editCopy;
	KAction* editPaste;
	KAction* editFont;
	KAction* editColor;
	KAction* editBgColor;

	KAction* chatSave;
	KAction* chatPrint;
	KAction* chatCloseAll;

	KAction *tabLeft;
	KAction *tabRight;
	KAction *tabDetach;
	KAction* tabClose;

	KToggleAction* viewToolBar;
	KToggleAction* viewMenuBar;
	KToggleAction* viewTabToolBar;
	
	KToggleAction* membersLeft;
	KToggleAction* membersRight;
	KToggleAction* membersNone;

	KActionMenu *actionSmileyMenu;
	KActionMenu *actionActionMenu;
	KActionMenu *actionContactMenu;
	KActionMenu *actionDetachMenu;
	KActionMenu *actionTabPlacementMenu;

	QString statusMsg;
	QPixmap protocolIcon;

signals:
	void closing(KopeteChatWindow*);

public slots:
	void slotSmileyActivated(int sm);
	void setActiveView( QWidget *active );
	void updateBackground( const QPixmap &pm );

private slots:

	void slotPrepareSmileyMenu();
	void slotPrepareContactMenu();
	void slotPrepareActionMenu();
	void slotPrepareDetachMenu();
	void slotPreparePlacementMenu();

	void slotCut();
	void slotCopy();
	void slotPaste();
	
	void slotSetBgColor();
	void slotSetFgColor();
	void slotSetFont();

	void slotHistoryUp();
	void slotHistoryDown();

	void slotSendMessage();
	void slotChatSave();
	void slotChatPrint();

	void slotPreviousTab();
	void slotNextTab();
	void slotDetachChat( int newWindowIndex = -1 );
	void slotPlaceTabs( int tabPlacement );

	void slotViewMenuBar();
	void slotViewToolBar();
	void slotViewTabToolBar();

	void slotConfKeys();
	void slotConfToolbar();

	void slotViewMembersLeft();
	void slotViewMembersRight();
	void slotViewMembersNone();
	const void slotEnableUpdateBg() { updateBg = true; }

	void slotSetCaption( bool );
	void slotChatClosed();

protected:
	virtual void closeEvent( QCloseEvent *e );
	virtual bool queryExit( );
	virtual void windowActivationChange(bool);

};

#endif
