 /*
    yahooimmessagemanager.cpp

    Copyright (c) 2003 by Duncan Mac-Vicar Prett <duncan@kde.org>

    Kopete    (c) 2002 by the Kopete developers  <kopete-devel@kde.org>

    *************************************************************************
    *                                                                       *
    * This program is free software; you can redistribute it and/or modify  *
    * it under the terms of the GNU General Public License as published by  *
    * the Free Software Foundation; either version 2 of the License, or     *
    * (at your option) any later version.                                   *
    *                                                                       *
    *************************************************************************
*/

#include <kdebug.h>

#include "kopetecontact.h"
#include "kopetemessagemanager.h"
#include "kopetemessagemanagerfactory.h"
#include "yahooprotocol.h"
#include "yahoocontact.h"
#include "kyahoo.h"
#include "yahooimmessagemanager.h"
#include "yahooimmessagemanager.moc"

YahooImMessageManager::YahooImMessageManager(   YahooSession *session_,
						const KopeteContact *user,
						KopeteContactPtrList others,
						const char *name)
					: KopeteMessageManager(user, others, YahooProtocol::protocol(), 0,
										   YahooProtocol::protocol(), name )
{

	// let Kopete's factory know about us
	KopeteMessageManagerFactory::factory()->addKopeteMessageManager(this);

	m_session = session_;
	m_otherId = others.first()->contactId();
	m_myId = user->contactId();

	// this slot will forward messages to the protocol
	QObject::connect( this, SIGNAL( messageSent( KopeteMessage&,
		KopeteMessageManager* ) ),
		this, SLOT( slotMessageSent( KopeteMessage&,
		KopeteMessageManager* ) ) );

	QObject::connect( this, SIGNAL(typingMsg(bool)), this, SLOT(slotTyping(bool)));

}

void YahooImMessageManager::slotMessageSent( KopeteMessage &message, KopeteMessageManager *)
{
	kdDebug(14130) << "[YahooImMessageManager] slotMessageSent called: " << message.body() << endl;

	// pass message on to protocol backend
	m_session->sendIm( m_myId, m_otherId, message.escapedBody() );

	// append message to window
	appendMessage(message);

	emit( messageSuccess() );
}

void YahooImMessageManager::slotTyping(bool isTyping_ )
{
	m_session->sendTyping( m_myId, m_otherId, isTyping_ );
}

YahooImMessageManager::~YahooImMessageManager()
{
}
